@@ -1,5 +1,5 @@
 from ckanext.drupal_idp.utils import Details
-import mock
+import unittest.mock as mock
 
 import pytest
 
@@ -25,5 +25,5 @@ def with_no_drupal_session(monkeypatch):
 
 @pytest.fixture
 def with_drupal_session(monkeypatch, details_data):
-    func = mock.Mock(return_value=Details(details_data))
+    func = mock.Mock(return_value=Details(**details_data))
     monkeypatch.setattr(utils, "get_user_details", func)
